aboutsummaryrefslogtreecommitdiffstats
path: root/src/jogl/classes/com/jogamp/graph/curve/tess
diff options
context:
space:
mode:
authorSven Göthel <[email protected]>2024-02-14 20:23:24 +0100
committerSven Göthel <[email protected]>2024-02-14 20:23:24 +0100
commite4b49663f6c6f138a8718847b68d1d78fba8fe73 (patch)
tree3628be91f48347a6b26ebf9d7e0809ddae1d4321 /src/jogl/classes/com/jogamp/graph/curve/tess
parent52277dc625b515ecc3ff0d26ca05428f3d973427 (diff)
Bug 1501: Refine convex == !complex: Use 'complex' term, have env-property toggle OutlineShape's isComplex() for visibility
We may use complex for other criteria than !convex, i.e. self-intersecting etc.
Diffstat (limited to 'src/jogl/classes/com/jogamp/graph/curve/tess')
-rw-r--r--src/jogl/classes/com/jogamp/graph/curve/tess/Triangulator.java12
1 files changed, 10 insertions, 2 deletions
diff --git a/src/jogl/classes/com/jogamp/graph/curve/tess/Triangulator.java b/src/jogl/classes/com/jogamp/graph/curve/tess/Triangulator.java
index eaebde076..a9f9b06c2 100644
--- a/src/jogl/classes/com/jogamp/graph/curve/tess/Triangulator.java
+++ b/src/jogl/classes/com/jogamp/graph/curve/tess/Triangulator.java
@@ -49,8 +49,16 @@ import com.jogamp.graph.geom.Triangle;
*/
public interface Triangulator {
- /** Mark the to be triangulated shape convex or non-convex, causing further processing costs if non-convex like intersection tests. Default is assuming a convex shape. */
- public void setConvexShape(boolean convex);
+ /**
+ * Mark the to be triangulated shape complex or non-complex.
+ * <p>
+ * Complex shapes may cause further processing costs, e.g. intersection tests to overcome self-intersecting shapes.
+ * </p>
+ * <p>
+ * Default is assuming a simple non-complex shape.
+ * </p>
+ */
+ public void setComplexShape(boolean complex);
/**
* Add a curve to the list of Outlines